# Testing the CLI
import filecmp
import os
import shutil
import tarfile

import delivery.delivery


def test_basic_rawdata_no_tar(tmpdir_factory):
    """
    Test that a directory in the source is copied to a directory in the destination in the manner expected.
    :return:
    """
    temp_directory = str(tmpdir_factory.mktemp('test_basic_rawdata_no_tar'))
    test_data_path = '../../../../shared/workspaces/test/test_data/spool/724126739/'
    eb_name = "17A-109.sb33151331.eb33786546.57892.65940042824"
    delivery.delivery.main(["-r", "-l", temp_directory, test_data_path])
    # compare the source and destination
    compare_dirs = filecmp.dircmp(temp_directory + "/" + eb_name, \
                                  (test_data_path + eb_name + "/rawdata/" + eb_name))
    # did the comparison report they are the same
    assert len(compare_dirs.left_only) == 0 and len(compare_dirs.right_only) == 0 and \
           len(compare_dirs.funny_files) == 0

def test_basic_rawdata_with_tar(tmpdir_factory):
    temp_directory = str(tmpdir_factory.mktemp('test_basic_rawdata_with_tar'))
    test_data_path = '../../../../shared/workspaces/test/test_data/spool/724126739/'
    delivery.delivery.main(["-r", "-t", "-l", temp_directory, test_data_path])
    eb_name = "17A-109.sb33151331.eb33786546.57892.65940042824"
    tar_path = temp_directory + "/724126739.tar.gz"
    # does a tar exist where we think
    assert os.path.exists(tar_path)
    # is it the only thing there (did cleanup work)
    assert len(os.listdir(temp_directory)) == 1
    # is it actually a tar
    assert tarfile.is_tarfile(tar_path)
    # lets unpack it
    shutil.unpack_archive(tar_path, temp_directory + "/extracted")
    # did it output what we expect
    assert os.path.exists(temp_directory + "/extracted/" + eb_name)
    # compare the extracted results with the source
    compare_dirs = filecmp.dircmp(temp_directory + "/extracted/" + eb_name, \
                                  (test_data_path + eb_name + "/rawdata/" + eb_name))
    # is the source and extracted the same
    assert len(compare_dirs.left_only) == 0 and len(compare_dirs.right_only) == 0 and \
           len(compare_dirs.funny_files) == 0
